import assert from 'assert';
import index from '../index.js';

const key = 32;
const msg = "In cryptography, the ElGamal encryption system is an asymmetric key encryption algorithm for public-key cryptography which is based on the Diffie–Hellman key exchange. The system provides an additional layer of security by asymmetrically encrypting keys previously used for symmetric message encryption";
const [prv, pub] = index.getKeys(key);

const cypherText = index.encrypt(msg, pub);
const secretText = index.decrypt(cypherText, prv);
assert.equal(msg, secretText)

const number = 5;
const threshold = 3;
let shares = index.shareKey(prv, number, threshold).slice(-threshold);
const joinedKey = index.combineKeys(shares);
assert.equal(prv, joinedKey)

const partialCypher = shares.map(sh => index.decryptPartial(cypherText, sh));
let joinedMsg = index.combineDeciphers(partialCypher, pub);
assert.equal(msg, joinedMsg)

shares = index.shareText(msg, number, threshold);
joinedMsg = index.combineTexts(shares.slice(-threshold));
assert.equal(msg, joinedMsg)
